Improve this doc View Source

Used for configuring the interpolation markup. Defaults to `{{` and `}}`.

## Usage

`$interpolateProvider();`

## Methods

- ###

  `startSymbol([value]);`

  Symbol to denote start of expression in the interpolated string. Defaults to `{{`.

  #### Parameters

  Param | Type | Details
  --- | --- | ---
  value (optional) | string | new value to set the starting symbol to.

  #### Returns

  stringself | Returns the symbol when used as getter and self if used as setter.

- ###

  `endSymbol([value]);`

  Symbol to denote the end of expression in the interpolated string. Defaults to `}}`.

  #### Parameters

  Param | Type | Details
  --- | --- | ---
  value (optional) | string | new value to set the ending symbol to.

  #### Returns

  stringself | Returns the symbol when used as getter and self if used as setter.

## Example

Edit in Plunker

    <script>
    var customInterpolationApp = angular.module('customInterpolationApp', []);

    customInterpolationApp.config(function($interpolateProvider) {
      $interpolateProvider.startSymbol('//');
      $interpolateProvider.endSymbol('//');
    });

    customInterpolationApp.controller('DemoController', function() {
        this.label = "This binding is brought you by // interpolation symbols.";
    });
    </script>
    <div ng-app="App" ng-controller="DemoController as demo">
      //demo.label//
    </div>

    it('should interpolate binding with custom symbols', function() {
    expect(element(by.binding('demo.label')).getText()).toBe('This binding is brought you by // interpolation symbols.');
    });